@@ -34,6 +34,7 @@
 #include "gnothello.h"
 #include "othello.h"
 #include "properties.h"
+#include "games-network.h"
 #include "network.h"
 
 GnomeAppBar *appbar;
@@ -236,7 +237,7 @@ quit_game_cb (GtkWidget *widget, gpointer data)
 static void
 new_network_game_cb (GtkWidget *widget, gpointer data)
 {
-  network_new ();
+  network_new (window);
 }
 
 void
@@ -534,7 +535,7 @@ load_pixmaps (void)
 
 	if (! g_file_test (fname,
 			   G_FILE_TEST_EXISTS | G_FILE_TEST_IS_REGULAR)) {
-		g_print (_("Could not find \'%s\' pixmap file for Iagno\n"), fname);
+		g_print (_("Could not find \'%s\' pixmap file\n"), fname);
 		exit (1);
 	}
 
@@ -927,7 +928,6 @@ main (int argc, char **argv)
 	client= gnome_master_client ();
 
 	g_object_ref (G_OBJECT (client));
-	gtk_object_sink (G_OBJECT (client));
 
 	g_signal_connect (G_OBJECT (client), "save_yourself",
 			  G_CALLBACK (save_state), argv[0]);
